@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 __author__   = 'Petter Reinholdtsen <pere@hungry.com>'
-__version__  = '0.44'
-__homepage__ = 'https://salsa.debian.org/debian/isenkram.git'
+__version__  = '0.45'
+__homepage__ = 'https://salsa.debian.org/debian/isenkram'
 __summary__  = 'Suggest packages to install when inserting new hardware.'
 __license__  = 'GPL'
